@@ -68,8 +68,8 @@ print_svc_client(addr, full)
 {
 	struct svc_client client;
 
-	memread(addr, sizeof(client), &client, "svc_client");
 	mprintf(FPTR " ", addr);
+	memread(addr, sizeof(client), &client, "svc_client");
 	mprintf("%5x ", client.cl_naddr);
 #ifdef _svc_client_has_cl_umap
 	mprintf("%8x ", htonl(client.cl_addr[0].s_addr));
@@ -79,7 +79,14 @@ print_svc_client(addr, full)
 		mprintf("       - ");
 	mprintf(FPTR " ", client.cl_umap);
 #endif /*_svc_client_has_cl_addr*/
-	mprintstr(client.cl_ident, sizeof(client.cl_ident));
+	if (sizeof(client.cl_ident) > sizeof(char *)) {
+		mprintstr(client.cl_ident, sizeof(client.cl_ident));
+	} else {
+		char buf[128];
+		memread((addr_t)client.cl_ident, sizeof(buf), buf,
+			"svc_client.cl_ident");
+		mprintstr(buf, sizeof(buf));
+	}
 	mprintf("\n");
 	if (full) {
 #ifdef _svc_client_has_cl_list
