@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -189,9 +189,16 @@ print_task(addr, full)
 #ifdef _task_struct_has_p_osptr
 	mprintf("\tpptr:       " FPTR "  (task_struct)\n", ts.p_pptr);
 #endif
+#ifdef _task_struct_has_times
 	mprintf("\ttimes:      %lx %lx / %lx %lx\n",
 		ts.times.tms_utime,  ts.times.tms_stime,
 		ts.times.tms_cutime, ts.times.tms_cstime);
+#endif
+#ifdef _task_struct_has_cstime
+	mprintf("\ttimes      %d %d / %d %d\n",
+		ts.utime.tv_sec, ts.stime.tv_sec,
+		ts.cutime.tv_sec, ts.cstime.tv_sec);
+#endif
 #if 0
 	mprintf("\tuid(,e,s,fs): %5d %5d %5d %5d\n",
 		ts.uid, ts.euid, ts.suid, ts.fsuid);
