@@ -137,7 +137,11 @@ print_file(addr, full)
 		mprintf("\tmapping:    " FPTR "\n", f.f_mapping);
 #endif
 	}
+#ifndef _file_has_f_list
+	return (addr_t)f.f_u.fu_list.next;
+#else
 	return (addr_t)f.f_list.next;
+#endif
 }
 
 void
@@ -334,7 +338,11 @@ print_superblock(addr, full)
 		addr_t faddr = (addr_t)sb.s_files.next;
 		prhead_file();
 		while (faddr != addr + OFFSET(struct super_block, s_files)) {
+#ifndef _file_has_f_list
+			faddr = print_file(faddr - OFFSET(struct file, f_u.fu_list),
+#else
 			faddr = print_file(faddr - OFFSET(struct file, f_list),
+#endif
 0);
 		}
 		mprintf("\n");
