@@ -63,7 +63,7 @@ print_gendisk(addr, full)
 	mprint_kobject(&disk.kobj);
 	mprintf("random       " FPTR "\n", disk.random);
 	mprintf("sync_io      %x\n", disk.sync_io);
-	mprintf("stamp        %lx %lx\n", disk.stamp, disk.stamp_idle);
+	mprintf("stamp        %lx\n", disk.stamp);
 #ifdef CONFIG_SMP
 	mprintf("disk_stats   " FPTR "  (" FPTR ")\n", disk.dkstats,
 		~(addr_t)disk.dkstats);
