@@ -52,7 +52,7 @@ print_page(addr, lru)
 	mprintf((n == -1)? "%4d ": "%4x", n);
 #else
 #ifdef _page_has_mapcount
-	n = ATOMIC_READ(pg.mapcount);
+	n = pg.mapcount;
 	mprintf((n == -1)? "%4d ": "%4x", n);
 #else
 	mprintf(FPTR, pg.pte.direct);
@@ -151,20 +151,19 @@ void
 print_gfp(gfp)
 	int gfp;
 {
-	const char *p = NULL;
+	const char *p;
 
 	mprintbit(gfpbit, gfp);
-	switch (gfp) {
-	case GFP_ATOMIC:	p = "ATOMIC";	break;
-	case GFP_NOIO:		p = "NOIO";	break;
-	case GFP_NOFS:		p = "NOFS";	break;
-	case GFP_KERNEL:	p = "KERNEL";	break;
-#if GFP_USER != GFP_KERNEL
-	case GFP_USER:		p = "USER";	break;
-#endif
-	case GFP_HIGHUSER:	p = "HIGHUSER";	break;
-	case GFP_DMA:		p = "DMA";	break;
-	}
+
+	if (gfp == GFP_ATOMIC)		p = "ATOMIC";
+	else if (gfp == GFP_NOIO)	p = "NOIO";
+	else if (gfp == GFP_NOFS)	p = "NOFS";
+	else if (gfp == GFP_KERNEL)	p = "KERNEL";
+	else if (gfp == GFP_USER)	p = "USER";
+	else if (gfp == GFP_HIGHUSER)	p = "HIGHUSER";
+	else if (gfp == GFP_DMA)	p = "DMA";
+	else				p = NULL;
+
 	if (p) {
 		mprintf("  (GFP_%s)\n", p);
 	} else {
