@@ -131,6 +131,9 @@ print_task(addr, full)
 	case TASK_INTERRUPTIBLE:	c = 'I';	break;
 	case TASK_UNINTERRUPTIBLE:	c = 'U';	break;
 	case TASK_STOPPED:		c = 'T';	break;
+#ifdef TASK_TRACED
+	case TASK_TRACED:		c = 't';	break;
+#endif
 #ifdef TASK_ZOMBIE
 	case TASK_ZOMBIE:		c = 'Z';	break;
 #endif
@@ -142,6 +145,9 @@ print_task(addr, full)
 #endif
 #ifdef EXIT_DEAD
 	case EXIT_DEAD:			c = 'D';	break;
+#endif
+#ifdef TASK_NONINTERACTIVE
+	case TASK_NONINTERACTIVE:	c = 'N';	break;
 #endif
 	default:			c = '?';	break;
 	}
@@ -322,9 +328,16 @@ print_mm_struct(addr, vflag)
 			mm.env_start, mm.env_end);
 		mprintf("total_vm    %lx\n", mm.total_vm);
 		mprintf("locked_vm:  %lx\n", mm.locked_vm);
+#ifdef _mm_struct_has__file_rss
+		mprintf("_file_rss:  %lx\n", mm._file_rss);
+#endif
+#ifdef _mm_struct_has__asnon_rss
+		mprintf("_asnon_rss:  %lx\n", mm._asnon_rss);
+#endif
 #ifdef _mm_struct_has__rss
 		mprintf("_rss:       %lx\n", mm._rss);
-#else
+#endif
+#ifdef _mm_struct_has_rss
 		mprintf("rss:        %lx\n", mm.rss);
 #endif
 		mprintf("def_flags:  %lx\n", mm.def_flags);
