@@ -8,11 +8,11 @@
 #include <linux/spinlock.h>
 #include <linux/slab.h>
 #include <linux/init.h>
-#if SUBLEVEL>=9
+#include "flags_slab.h"
+#ifdef _slab_rcu_has_head
 #include <linux/rcupdate.h>
 #endif
 #include "slab.h"
-#include "flags_slab.h"
 
 addr_t print_slab();
 addr_t print_kmem_cache();
@@ -150,9 +150,37 @@ print_kmem_cache(addr, sflag, full, next)
 	} else {
 		mprintf("addr: " FPTR "\n", addr);
 #ifdef _kmem_cache_s_has_array
-		mprintf("array[0]      " FPTR "\n", cache.array[0]);
+		int i;
+
+		mprintf("array[%x]    ", NR_CPUS);
+		{	int i;
+			for (i = 0; i < NR_CPUS; i++) {
+				if (cache.array[i])
+					mprintf(" " FPTR, cache.array[i]);
+				else
+					mprintf(" -");
+			}
+		}
+		mprintf("\n");
+#endif
+#ifdef _kmem_cache_s_has_batchcount
+		mprintf("batchcount   %x\n", cache.batchcount);
+#endif
+#ifdef _kmem_cache_s_has_limit
+		mprintf("limit        %x\n", cache.limit);
+#endif
+#ifdef _kmem_cache_s_has_shared
+		mprintf("shared       %x\n", cache.shared);
 #endif
 		mprintf("objsize      %x\n", cache.objsize);
+#ifdef _kmem_cache_s_has_nodelists
+		mprintf("nodelists[%x]", MAX_NUMNODES);
+		{	int i;
+			for (i = 0; i < MAX_NUMNODES; i++)
+				mprintf(" " FPTR, cache.nodelists[i]);
+			mprintf("\n");
+		}
+#endif
 		mprintf("flags        %x\n", cache.flags);
 		mprintf("num          %x\n", cache.num);
 #ifdef _kmem_cache_s_has_free_limit
@@ -215,7 +243,39 @@ search_slab(addr)
 		cnt = 0;
 
 #ifdef _kmem_cache_s_has_nodelists
-#warning "not implimented"
+		int i;
+		for (i = 0; i < MAX_NUMNODES; i++) {
+			struct kmem_list3 nlist;
+			if (cache.nodelists[i] == NULL)
+				continue;
+			memread((addr_t)cache.nodelists[i], sizeof(nlist),
+				&nlist, "kmem_list3");
+
+			saddr = (addr_t)nlist.slabs_full.next - OFFSET(struct slab, list);
+			while (saddr && saddr != (addr_t)cache.nodelists[i] + OFFSET(struct kmem_list3, slabs_full)) {
+				memread(saddr, sizeof(slab), &slab, "slab_t");
+				if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
+					goto found;
+				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
+				if (++cnt > 100000) {
+					mprintf("loop? (%lx full)\n", kmaddr);
+					break;
+				}
+
+			}
+			cnt = 0;
+			saddr = (addr_t)nlist.slabs_partial.next - OFFSET(struct slab, list);
+			while (saddr && saddr != (addr_t)cache.nodelists[i] + OFFSET(struct kmem_list3, slabs_partial)) {
+				memread(saddr, sizeof(slab), &slab, "slab_t");
+				if (addr >= (addr_t)slab.s_mem && addr < (addr_t)slab.s_mem + len)
+					goto found;
+				saddr = (addr_t)slab.list.next - OFFSET(struct slab, list);
+				if (++cnt > 100000) {
+					mprintf("loop? (%lx partial)\n", kmaddr);
+					break;
+				}
+			}
+		}
 
 #else /*_kmem_cache_s_has_nodelists*/
 		saddr = (addr_t)cache.lists.slabs_full.next - OFFSET(struct slab, list);
