@@ -3,7 +3,8 @@
  *   */
 
 #include <string.h>
-#include "asm/page.h"
+#define _LINUX_CONFIG_H
+#include <asm/page.h>
 #include "crash.h"
 #include "stacksize.h"
 
