@@ -219,10 +219,10 @@ PRIVATE const pte_t *
 load_pte(addr)
 	addr_t addr;
 {
-	if (pte_cache == addr)
-		return pte_buffer; /*cache hit*/
-	ll_memread(addr, PAGE_SIZE, pte_buffer, "pte");
-	pte_cache = addr;
+	if (pte_cache != addr) {
+		pte_cache = addr;
+		ll_memread(addr, PAGE_SIZE, pte_buffer, "pte");
+	}
 	return pte_buffer;
 }
 
