@@ -140,20 +140,22 @@ trace()
 				esp += funchead[i + 2];
 				i += 3;
 				break;	/* for sys_lstat64 */
-			/* add esp,xx */
+#if 0
+			/* add esp,xx */	/*XXX*/
 			} else if (c == 0x83 && i < sizeof(funchead) - 2 && funchead[i + 1] == 0xc4) {
 				/* unsigned? but it makes loop */
 				esp += funchead[i + 2];
 				i += 3;
 				continue;
+#endif
 			/* sub esp,xx */
 			} else if (c == 0x81 && i < sizeof(funchead) - 3 && funchead[i + 1] == 0xec) {
 				esp += funchead[i + 2] + funchead[i + 3] * 256;
 				i += 6;
 				continue;
-			/* push es/push cs/push ss/push ds */
-			} else if (c == 0x06 || c == 0x0e || c == 0x16 || c == 0x1e) {
-				esp += 4;
+			/* push es/push cs/push ss/push ds/push imm/pushf */
+			} else if (c == 0x06 || c == 0x0e || c == 0x16 || c == 0x1e || c == 0x68 || c == 0x6a || c == 0x9c) {
+				esp += sizeof(addr_t);
 			/* GRP-A */
 			} else if (code1[c].type == GROUPA) {
 				i += code1[c].nbyte;
@@ -230,11 +232,11 @@ trace()
 		    (strcmp(sym->name, "stext_lock") == 0 || strncmp(sym->name, "_text_lock_", 11) == 0 || strncmp(sym->name, ".text.lock.", 11) == 0)) {
 			mprintf(")\n[%8lx] %8lx  [%s]\n", esp, retad, getsymstr(retad));
 			if (funchead[0] == 0xe9)
-				retad += *(unsigned int *)&funchead[1];
+				retad += *(unsigned int *)&funchead[1] + 5;
 			else if (funchead[1] == 0xe9)
-				retad += *(unsigned int *)&funchead[2];
+				retad += *(unsigned int *)&funchead[2] + 6;
 			else
-				retad += *(unsigned int *)&funchead[3];
+				retad += *(unsigned int *)&funchead[3] + 7;
 			sym = searchsym_byaddr(retad);
 			continue;
 		}
@@ -243,6 +245,8 @@ trace()
 			int c = funchead[i];
 			/* add esp,xx */
 			if (c == 0x83 && funchead[i + 1] == 0xc4) {
+				if (i >= sizeof(funchead) - 2 || funchead[i + 2] >= 0x40)
+					break;
 				if (argsize == 0 && i < sizeof(funchead) - 3 && funchead[i + 3] != 0xc3)
 					argsize = (signed char)funchead[i + 2];
 				break;
@@ -260,7 +264,7 @@ trace()
 			} else if (c == 0xe9) {
 				if (i > 0)
 					break;
-				memread(retad + i + 5 + funchead[1] + funchead[2] * 256, sizeof(funchead), funchead, "jmp(e9)");
+				memread(retad + 5 + funchead[1] + funchead[2] * 256, sizeof(funchead), funchead, "jmp(e9)");
 				/* add esp,xx */
 				if (funchead[0] == 0x83 && funchead[1] == 0xc4)
 					argsize = (signed char)funchead[2];
@@ -269,7 +273,7 @@ trace()
 			} else if (c == 0xeb) {
 				if (i > 0)
 					break;
-				memread(retad + i + 2 + (signed char)funchead[1], sizeof(funchead), funchead, "jmp(eb)");
+				memread(retad + 2 + (signed char)funchead[1], sizeof(funchead), funchead, "jmp(eb)");
 				/* add esp,xx */
 				if (funchead[0] == 0x83 && funchead[1] == 0xc4)
 					argsize = (signed char)funchead[2];
@@ -303,7 +307,7 @@ trace()
 					break;
 				mprintf("%x", *(int*)&stack[esp - stacktop + sizeof(int) + i]);
 			}
-		} else /*if (strcmp(sym->name, "system_call") == 0)*/ {
+		} else {
 			for (i = 0; i < 4 * sizeof(int); i += sizeof(int)) {
 				if (i) mprintf(",");
 				if (!INTHESTACK(esp + sizeof(int) + i))
