@@ -57,6 +57,7 @@ char *kerntype;
 
 int quiet = 0;
 int noprompt = 0;
+int debug = 0;
 
 void
 sighandler(signo)
@@ -787,7 +788,7 @@ char *argv[];
 	func_args[0] = argv[0];
 	fp = stdout;
 
-	while ((c = getopt(argc, argv, "p:q")) != EOF) {
+	while ((c = getopt(argc, argv, "p:qD")) != EOF) {
 		switch (c) {
 		case 'p':
 			physname = optarg;
@@ -795,6 +796,9 @@ char *argv[];
 		case 'q':
 			quiet = 1;
 			break;
+		case 'D':
+			debug = 1;
+			break;
 		default:
 			usage_abort(argv[0]);
 		}
