@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -134,7 +134,7 @@ print_pagebuf(addr, fflag)
 }
 
 void
-print_all_pagebuf(addr, fflag)
+print_all_pagebuf(addr, fflag, nhash)
 	addr_t addr;
 	int fflag;
 {
@@ -156,8 +156,11 @@ print_all_pagebuf(addr, fflag)
 	addr_t tmp;
 	int i;
 
+	if (nhash == 0)
+		nhash = NHASH;
+
 	prhead_pagebuf();
-	for (i = 0; i < NHASH; i++) {
+	for (i = 0; i < nhash; i++) {
 		memread(addr + sizeof(pbh) * i, sizeof(pbh), &pbh, "pbhash");
 #if !defined(XFS_NOPAGEBUF_H)	/*XXX*/
 		if (pbh.pb_count == 0)
@@ -170,3 +173,52 @@ print_all_pagebuf(addr, fflag)
 	}
 #endif /*_page_buf_s_has_pb_hash_list*/
 }
+
+addr_t
+print_xfs_buftarg(addr, bflag)
+	addr_t addr;
+	int bflag;
+{
+#ifdef _xfs_buftarg_has_pbr_dev
+	struct xfs_buftarg bt;
+
+	mprintf("addr      " FPTR "\n", addr);
+	memread(addr, sizeof(bt), &bt, "xfs_buftarg");
+
+	mprintf("dev       ");
+	mprint_dev_t(bt.pbr_dev);
+	mprintf("\n");
+	mprintf("bdev      " FPTR "\n", bt.pbr_bdev);
+	mprintf("mapping   " FPTR "\n", bt.pbr_mapping);
+	mprintf("bsize     %x (2^%x)\n", bt.pbr_bsize, bt.pbr_sshift);
+#ifdef _xfs_buftarg_has_hash
+	mprintf("hashmask  %x (2^%x)\n", bt.bt_hashmask, bt.bt_hashshift);
+	mprintf("hash      " FPTR "\n", bt.bt_hash);
+
+	if (bflag)
+		print_all_pagebuf(bt.bt_hash, 0, bt.bt_hashmask + 1);
+#endif /*_xfs_buftarg_has_hash*/
+#endif /*_xfs_buftarg_has_pbr_dev*/
+
+#ifdef _pb_target_has_pbr_device
+	struct pb_target bt;
+
+	mprintf("addr      " FPTR "\n", addr);
+	memread(addr, sizeof(bt), &bt, "pb_target");
+
+	mprintf("dev       ");
+	mprint_kdev_t(bt.pbr_device);
+	mprintf("\n");
+	mprintf("blocksize %x (2^%x)\n", bt.pbr_blocksize, bt.pbr_blocksize_bits);
+#ifdef _pb_target_has_pbr_bdev
+	mprintf("bdev      " FPTR "\n", bt.pbr_bdev);
+#endif
+#ifdef _pb_target_has_pbr_mapping
+	mprintf("mapping   " FPTR "\n", bt.pbr_mapping);
+#endif
+#ifdef _pb_target_has_pbr_addrspace
+	mprintf("addrspace " FPTR "\n", bt.pbr_addrspace);
+#endif
+#endif /*_pb_target_has_pbr_device*/
+	return 0;
+}
