@@ -11,7 +11,13 @@
 void
 prhead_xfs_vfs()
 {
+#if 1
+	/* new style */
+	mprintf(SPTR" "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
+#else
+	/* old fashion */
 	mprintf(SPTR" BUSY BSIZE "SPTR" "SPTR"\n", "ADDR", "BH-FIRST", "SUPER");
+#endif
 }
 
 addr_t
@@ -23,6 +29,11 @@ print_xfs_vfs(addr)
 	memread(addr, sizeof(vfs), &vfs, "vfs_t");
 	mprintf(FPTR " ", addr);
 
-	mprintf("%4x %5x " FPTR " " FPTR "\n", vfs.vfs_busycnt, vfs.vfs_bsize, vfs.vfs_bh.bh_first, vfs.vfs_super);
+#if 1
+#else
+	/* old fashion */
+	mprintf("%4x %5x ", vfs.vfs_busycnt, vfs.vfs_bsize);
+#endif
+	mprintf(FPTR " " FPTR "\n", vfs.vfs_bh.bh_first, vfs.vfs_super);
 	return 0;
 }
