@@ -1,13 +1,15 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include <unistd.h>
 #include "crash.h"
 
-PRIVATE addr_t pagebuf();
+PRIVATE addr_t pagebuf(), xfs_buftarg();
 const commandtable_t command_pagebuf =
 	{"page_buf", pagebuf, "[-a] [-f] [address]", "[XFS] print page_buf_t table\n  -a  follow next\n  -f  more detail"};
+const commandtable_t command_xfs_buftarg =
+	{"xfs_buftarg", xfs_buftarg, "[-b] address", "[XFS] print xfs_buftarg table\n  -b  show pagebuf from hash"};
 
 extern void prhead_pagebuf();
 extern addr_t print_pagebuf();
@@ -45,7 +47,35 @@ pagebuf()
 		}
 	} else {
 		GETADDR(pbhash);
-		print_all_pagebuf(pbhash_addr, fflag);
+		print_all_pagebuf(pbhash_addr, fflag, 0);
+	}
+	return addr;
+}
+
+PRIVATE addr_t
+xfs_buftarg()
+{
+	int i, c;
+	addr_t start, addr = 0;
+	int bflag = 0;
+
+	while ((c = getopt(argcnt, args, "b")) != EOF) {
+		switch (c) {
+		case 'b':
+			bflag = 1;
+			break;
+		default:
+			THROW(usage);
+		}
+	}
+
+	if (argcnt > optind) {
+		for (i = optind; i < argcnt; i++) {
+			addr = getvalue(args[i]);
+			addr = print_xfs_buftarg(addr, bflag);
+		}
+	} else {
+		THROW(usage);
 	}
 	return addr;
 }
