@@ -4,6 +4,7 @@ extern const commandtable_t
 	command_pagebuf,
 	command_xfs_alloc_arg,
 	command_xfs_bmbt_rec,
+	command_xfs_buftarg,
 	command_xfs_inode,
 	command_xfs_log_item,
 	command_xfs_mount,
@@ -18,6 +19,7 @@ const commandtable_t *commandtable_xfs[] = {
 	&command_pagebuf,
 	&command_xfs_alloc_arg,
 	&command_xfs_bmbt_rec,
+	&command_xfs_buftarg,
 	&command_xfs_inode,
 	&command_xfs_log_item,
 	&command_xfs_mount,
